==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="121"/>
        <source>FFmpeg Plugin</source>
        <translation>Wtyczka FFMPEG</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="123"/>
        <source>FFmpeg Formats</source>
        <translation>Formaty FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="192"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>O wtyczce FFmpeg Audio</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="194"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Wtyczka FFmpeg Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="196"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Skompilowane przy użyciu libavformat-%1.%2.%3 i libavcodec-%4.%5.%6</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="204"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Ustawienia wtyczki FFMPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formaty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ALAC (Apple Lossless Audio Codec)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>ADTS AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>MPEG-4 AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>RealAudio 1.0/2.0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Shorten</source>
        <translation>Shorten (SHN)</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="121"/>
        <source>FFmpeg Plugin</source>
        <translation>Wtyczka FFMPEG</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="123"/>
        <source>FFmpeg Formats</source>
        <translation>Formaty FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="192"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>O wtyczce FFmpeg Audio</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="194"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Wtyczka FFmpeg Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="196"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Skompilowane przy użyciu libavformat-%1.%2.%3 i libavcodec-%4.%5.%6</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="204"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="61"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Ustawienia wtyczki FFMPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formaty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ALAC (Apple Lossless Audio Codec)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>ADTS AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>MPEG-4 AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>RealAudio 1.0/2.0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Shorten</source>
        <translation>Shorten (SHN)</translation>
    </message>
</context>
</TS>
